/*
    SDP Editor
    Copyright 2006 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Martin Storsj
    martin@martin.st
*/

#ifndef __SERVICESEARCHER_H
#define __SERVICESEARCHER_H

#include <e32base.h>
#include <btextnotifiers.h>
#include <btsdp.h>
#include <bt_sock.h>

#define KOBEX 0x0008

class CServiceSearcher : public CBase, public MSdpAgentNotifier, public MSdpAttributeValueVisitor {
public:

	CServiceSearcher();
	~CServiceSearcher();

	enum TFindType { EFindChannel, EFindHandle };

	void FindServiceChannelL(TUUID& aUuid, TBTDevAddr& aAddr, TRequestStatus& aStatus);
	void FindServiceHandleL(TUUID& aUuid, TBTDevAddr& aAddr, TRequestStatus& aStatus);
	void FindServiceL(TUUID& aUuid, TBTDevAddr& aAddr, TRequestStatus& aStatus);
	void CancelFind();
	TInt GetChannel();
	TSdpServRecordHandle GetHandle();

	void AttributeRequestComplete(TSdpServRecordHandle aHandle, TInt aError);
	void AttributeRequestResult(TSdpServRecordHandle aHandle, TSdpAttributeID aAttrID, CSdpAttrValue* aAttrValue);
	void NextRecordRequestComplete(TInt aError, TSdpServRecordHandle aHandle, TInt aTotalRecordsCount);

	void VisitAttributeValueL(CSdpAttrValue& aValue, TSdpElementType aType);
	void StartListL(CSdpAttrValueList& aList);
	void EndListL();

private:
	void AttributeRequestCompleteL(TSdpServRecordHandle aHandle, TInt aError);
	void AttributeRequestResultL(TSdpServRecordHandle aHandle, TSdpAttributeID aAttrID, CSdpAttrValue* aAttrValue);
	void NextRecordRequestCompleteL(TInt aError, TSdpServRecordHandle aHandle, TInt aTotalRecordsCount);

	void Finished(TInt aError);

private:
	TUUID iUuid;
	CSdpAgent* iAgent;
	CSdpSearchPattern* iSdpSearchPattern;
	TRequestStatus* iServiceFindStatus;
	TBool iServiceFound;

	TInt iFindType;
	TInt iIndex;
	TInt iChannel;
	TSdpServRecordHandle iHandle;
};

#endif
